#!/bin/bash
#
# $Id$
#
# FancyLibs
#
# Copyright (C) 2014 ITEG IT-Engineers GmbH
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

NWIF="$1"
shift

# further options are passed to ifup, too
# i.e. -i /etc/network/interfaces.home


if [ -z "${NWIF}" ] ; then
  MSG="fancysock-ifup: ERROR: No network interface specified to bring up, aborting"
  logger -t fancysock -p user.error -s -- ${MSG}
  exit 1 
fi

if [ "$UID" = "0" ] ; then
  IFCALL="/sbin/ifup ${NWIF} $*"  
else
  IFCALL="/usr/bin/sudo /sbin/ifup ${NWIF} $*"  
fi

IFLOG="/tmp/ifup_$$.log"

echo "Calling ${IFCALL}"

${IFCALL} 2>&1 |tee -a ${IFLOG}
PRC=${PIPESTATUS[0]}

if [ "$PRC" = "0" ] ; then
  # /sys/class/net/${NWIF} does not work for alias interfaces
  IFCONF=$(/sbin/ifconfig |egrep "^${NWIF}[ :]") 
  if [ -z "${IFCONF}" ] ; then
    MSG="ERROR: ${IFCALL} succeeded, but ifconfig fails to list ${NWIF}."
    echo "$MSG"
    logger -t fancysock -p user.error -- fancysock-ifup: ${MSG} Output follows.
    logger -t fancysock -p user.error -f ${IFLOG}
    rm -f ${IFLOG}
    exit 11
  fi
  MSG="Successfully brought up ${NWIF}"
  echo "$MSG"
  logger -t fancysock -p user.notice -- fancysock-ifup:${MSG}
  rm -f ${IFLOG}
  exit 0
fi

MSG="ERROR: Failed to bring up ${NWIF} by calling ${IFCALL}."
echo "$MSG"
logger -t fancysock -p user.error -- fancysock-ifup: ${MSG} Output follows.
logger -t fancysock -p user.error -f ${IFLOG}
rm -f ${IFLOG}
exit $PRC
