#!/bin/bash
#
# $Id$
#
# FancyLibs
#
# Copyright (C) 2014 ITEG IT-Engineers GmbH
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

NWIF="$1"
shift

if [ -z "${NWIF}" ] ; then
  MSG="fancysock-wlan-status: ERROR: No network interface specified to bring down, aborting"
  logger -t fancysock -p user.error -s -- ${MSG}
  exit 1 
fi

REPORTFILE="$1"
shift
if [ -z "${NWIF}" ] ; then
  REPORTFILE="/tmp/fancysockwlan-NN-status.txt"
fi
test -f ${REPORTFILE} && rm -f ${REPORTFILE} 

IWCALL="/sbin/iwconfig ${NWIF}"  

IWLOG="/tmp/iwconfig_$$.log"

echo "Calling ${IWCALL}, logging to ${IWLOG}"

${IWCALL} 2>&1 >${IWLOG}
PRC=${PIPESTATUS[0]}

if [ "$PRC" != "0" ] ; then
  echo "status=down" |tee -a ${REPORTFILE}
  MSG="ERROR: Failed to call iwconfig ${NWIF}."
  echo "$MSG"
  logger -t fancysock -p user.error -- fancysock-wlan-status: ${MSG} Output follows.
  logger -t fancysock -p user.error -f ${IWLOG}
  rm -f ${IWLOG}
  exit $PRC
fi

# Connected?

WLANOFFLINE=$(egrep -i "Access Point: Not-Associated|ESSID:off" ${IWLOG})
if [ -n "${WLANOFFLINE}" ] ; then
  echo "status=not connected" |tee -a ${REPORTFILE}
  MSG="WARNING: WLAN not connected."
  echo "$MSG"
  logger -t fancysock -p user.warning -- fancysock-wlan-status: ${MSG} Output follows.
  logger -t fancysock -p user.warning -f ${IWLOG}
  rm -f ${IWLOG}
  exit 0
fi

SIGNALLEVEL=$(grep -i "Signal level=" ${IWLOG} |cut -f3 -d'=' |cut -f1 -d' ')
if [ -z "${SIGNALLEVEL}" ] ; then
  echo "status=not connected" |tee -a ${REPORTFILE}
  MSG="ERROR: Unable to parse signal level from iwconfig output."
  echo "$MSG"
  logger -t fancysock -p user.warning -- fancysock-wlan-status: ${MSG} Output follows.
  logger -t fancysock -p user.warning -f ${IWLOG}
  rm -f ${IWLOG}
  exit 0
fi

echo "status=connected" |tee -a ${REPORTFILE}

echo "signal level=${SIGNALLEVEL}" |tee -a ${REPORTFILE}

LINKQUALITY=$(grep -i "Link Quality=" ${IWLOG} |cut -f2 -d'=' |cut -f1 -d' ')
echo "link quality=${LINKQUALITY}" |tee -a ${REPORTFILE}

ESSID=$(grep -i "ESSID:" ${IWLOG} |cut -f2 -d':' |tr -d '"')
echo "essid=${ESSID}" |tee -a ${REPORTFILE}

APMAC=$(grep -i "Access Point: " ${IWLOG} |cut -f4- -d':' |tr -d ' ')
echo "access point=${APMAC}" |tee -a ${REPORTFILE}

MSG="Successfully collected infos about WLAN connection"
logger -t fancysock -p user.notice -- fancysock-wlan-status: ${MSG} Detected details follow.
logger -t fancysock -p user.notice -f ${REPORTFILE}

exit 0
